from canvas_generated.messages import effects_pb2 as _effects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN: _ClassVar[EventType]
    ALLERGY_INTOLERANCE_CREATED: _ClassVar[EventType]
    ALLERGY_INTOLERANCE_UPDATED: _ClassVar[EventType]
    APPOINTMENT_CANCELED: _ClassVar[EventType]
    APPOINTMENT_CHECKED_IN: _ClassVar[EventType]
    APPOINTMENT_CREATED: _ClassVar[EventType]
    APPOINTMENT_NO_SHOWED: _ClassVar[EventType]
    APPOINTMENT_RESCHEDULED: _ClassVar[EventType]
    APPOINTMENT_RESTORED: _ClassVar[EventType]
    APPOINTMENT_UPDATED: _ClassVar[EventType]
    BILLING_LINE_ITEM_CREATED: _ClassVar[EventType]
    BILLING_LINE_ITEM_UPDATED: _ClassVar[EventType]
    CONDITION_ASSESSED: _ClassVar[EventType]
    CONDITION_CREATED: _ClassVar[EventType]
    CONDITION_RESOLVED: _ClassVar[EventType]
    CONDITION_UPDATED: _ClassVar[EventType]
    CONSENT_CREATED: _ClassVar[EventType]
    CONSENT_DELETED: _ClassVar[EventType]
    CONSENT_UPDATED: _ClassVar[EventType]
    COVERAGE_CREATED: _ClassVar[EventType]
    COVERAGE_UPDATED: _ClassVar[EventType]
    ENCOUNTER_CREATED: _ClassVar[EventType]
    ENCOUNTER_UPDATED: _ClassVar[EventType]
    IMAGING_REPORT_CREATED: _ClassVar[EventType]
    IMAGING_REPORT_UPDATED: _ClassVar[EventType]
    IMMUNIZATION_CREATED: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_CREATED: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_UPDATED: _ClassVar[EventType]
    IMMUNIZATION_UPDATED: _ClassVar[EventType]
    INSTRUCTION_CREATED: _ClassVar[EventType]
    INSTRUCTION_UPDATED: _ClassVar[EventType]
    INTERVIEW_CREATED: _ClassVar[EventType]
    INTERVIEW_UPDATED: _ClassVar[EventType]
    LAB_ORDER_CREATED: _ClassVar[EventType]
    LAB_ORDER_UPDATED: _ClassVar[EventType]
    LAB_REPORT_CREATED: _ClassVar[EventType]
    LAB_REPORT_UPDATED: _ClassVar[EventType]
    MEDICATION_LIST_ITEM_CREATED: _ClassVar[EventType]
    MEDICATION_LIST_ITEM_UPDATED: _ClassVar[EventType]
    MESSAGE_CREATED: _ClassVar[EventType]
    PATIENT_CREATED: _ClassVar[EventType]
    PATIENT_UPDATED: _ClassVar[EventType]
    PRESCRIPTION_CREATED: _ClassVar[EventType]
    PRESCRIPTION_UPDATED: _ClassVar[EventType]
    REFERRAL_REPORT_CREATED: _ClassVar[EventType]
    REFERRAL_REPORT_UPDATED: _ClassVar[EventType]
    TASK_COMMENT_CREATED: _ClassVar[EventType]
    TASK_CREATED: _ClassVar[EventType]
    TASK_LABELS_ADJUSTED: _ClassVar[EventType]
    TASK_UPDATED: _ClassVar[EventType]
    VITAL_SIGN_CREATED: _ClassVar[EventType]
    VITAL_SIGN_UPDATED: _ClassVar[EventType]
    CRON: _ClassVar[EventType]
    CARE_TEAM_MEMBERSHIP_CREATED: _ClassVar[EventType]
    CARE_TEAM_MEMBERSHIP_UPDATED: _ClassVar[EventType]
    CARE_TEAM_MEMBERSHIP_DELETED: _ClassVar[EventType]
    NOTE_STATE_CHANGE_EVENT_CREATED: _ClassVar[EventType]
    NOTE_STATE_CHANGE_EVENT_UPDATED: _ClassVar[EventType]
    PATIENT_ADDRESS_CREATED: _ClassVar[EventType]
    PATIENT_ADDRESS_UPDATED: _ClassVar[EventType]
    PATIENT_ADDRESS_DELETED: _ClassVar[EventType]
    PATIENT_CONTACT_PERSON_CREATED: _ClassVar[EventType]
    PATIENT_CONTACT_PERSON_UPDATED: _ClassVar[EventType]
    PATIENT_CONTACT_PERSON_DELETED: _ClassVar[EventType]
    PATIENT_CONTACT_POINT_CREATED: _ClassVar[EventType]
    PATIENT_CONTACT_POINT_UPDATED: _ClassVar[EventType]
    PATIENT_CONTACT_POINT_DELETED: _ClassVar[EventType]
    PROTOCOL_OVERRIDE_CREATED: _ClassVar[EventType]
    PROTOCOL_OVERRIDE_UPDATED: _ClassVar[EventType]
    PROTOCOL_OVERRIDE_DELETED: _ClassVar[EventType]
    TASK_COMMENT_UPDATED: _ClassVar[EventType]
    TASK_COMMENT_DELETED: _ClassVar[EventType]
    DEVICE_CREATED: _ClassVar[EventType]
    DEVICE_UPDATED: _ClassVar[EventType]
    OBSERVATION_CREATED: _ClassVar[EventType]
    OBSERVATION_UPDATED: _ClassVar[EventType]
    DETECTED_ISSUE_CREATED: _ClassVar[EventType]
    DETECTED_ISSUE_UPDATED: _ClassVar[EventType]
    TASK_CLOSED: _ClassVar[EventType]
    TASK_COMPLETED: _ClassVar[EventType]
    DETECTED_ISSUE_EVIDENCE_CREATED: _ClassVar[EventType]
    DETECTED_ISSUE_EVIDENCE_UPDATED: _ClassVar[EventType]
    PRE_COMMAND_ORIGINATE: _ClassVar[EventType]
    POST_COMMAND_ORIGINATE: _ClassVar[EventType]
    PRE_COMMAND_UPDATE: _ClassVar[EventType]
    POST_COMMAND_UPDATE: _ClassVar[EventType]
    PRE_COMMAND_COMMIT: _ClassVar[EventType]
    POST_COMMAND_COMMIT: _ClassVar[EventType]
    PRE_COMMAND_DELETE: _ClassVar[EventType]
    POST_COMMAND_DELETE: _ClassVar[EventType]
    PRE_COMMAND_ENTER_IN_ERROR: _ClassVar[EventType]
    POST_COMMAND_ENTER_IN_ERROR: _ClassVar[EventType]
    PRE_COMMAND_EXECUTE_ACTION: _ClassVar[EventType]
    POST_COMMAND_EXECUTE_ACTION: _ClassVar[EventType]
    POST_COMMAND_INSERTED_INTO_NOTE: _ClassVar[EventType]
    ASSESS_COMMAND__CONDITION_SELECTED: _ClassVar[EventType]
    MEDICATION_STATEMENT__MEDICATION__PRE_SEARCH: _ClassVar[EventType]
    MEDICATION_STATEMENT__MEDICATION__POST_SEARCH: _ClassVar[EventType]
    MEDICATION_STATEMENT__MEDICATION__SELECTED: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__POST_UPDATE: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__POST_COMMIT: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__PRE_DELETE: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__POST_DELETE: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    ADJUST_PRESCRIPTION_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__PRESCRIBE__POST_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__PRESCRIBE__PRE_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__INDICATIONS__PRE_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__INDICATIONS__POST_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__PHARMACY__PRE_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__PHARMACY__POST_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__CHANGE_MEDICATION_TO__PRE_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__CHANGE_MEDICATION_TO__POST_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__SUPERVISING_PROVIDER__PRE_SEARCH: _ClassVar[EventType]
    ADJUST_PRESCRIPTION__SUPERVISING_PROVIDER__POST_SEARCH: _ClassVar[EventType]
    ALLERGY_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    ALLERGY_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    ALLERGY_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    ALLERGY_COMMAND__POST_UPDATE: _ClassVar[EventType]
    ALLERGY_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    ALLERGY_COMMAND__POST_COMMIT: _ClassVar[EventType]
    ALLERGY_COMMAND__PRE_DELETE: _ClassVar[EventType]
    ALLERGY_COMMAND__POST_DELETE: _ClassVar[EventType]
    ALLERGY_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    ALLERGY_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    ALLERGY_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    ALLERGY_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    ALLERGY_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    ALLERGY__ALLERGY__PRE_SEARCH: _ClassVar[EventType]
    ALLERGY__ALLERGY__POST_SEARCH: _ClassVar[EventType]
    ASSESS_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    ASSESS_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    ASSESS_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    ASSESS_COMMAND__POST_UPDATE: _ClassVar[EventType]
    ASSESS_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    ASSESS_COMMAND__POST_COMMIT: _ClassVar[EventType]
    ASSESS_COMMAND__PRE_DELETE: _ClassVar[EventType]
    ASSESS_COMMAND__POST_DELETE: _ClassVar[EventType]
    ASSESS_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    ASSESS_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    ASSESS_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    ASSESS_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    ASSESS_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    ASSESS__CONDITION__POST_SEARCH: _ClassVar[EventType]
    ASSESS__CONDITION__PRE_SEARCH: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__POST_UPDATE: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__POST_COMMIT: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__PRE_DELETE: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__POST_DELETE: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    CANCEL_PRESCRIPTION_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    CANCEL_PRESCRIPTION__SELECTED_PRESCRIPTION__PRE_SEARCH: _ClassVar[EventType]
    CANCEL_PRESCRIPTION__SELECTED_PRESCRIPTION__POST_SEARCH: _ClassVar[EventType]
    CHART_SECTION_REVIEW_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    CHART_SECTION_REVIEW_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    CHART_SECTION_REVIEW_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    CHART_SECTION_REVIEW_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    CHART_SECTION_REVIEW_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    CHART_SECTION_REVIEW_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    CLIPBOARD_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    CLIPBOARD_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    CLIPBOARD_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    CLIPBOARD_COMMAND__POST_UPDATE: _ClassVar[EventType]
    CLIPBOARD_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    CLIPBOARD_COMMAND__POST_COMMIT: _ClassVar[EventType]
    CLIPBOARD_COMMAND__PRE_DELETE: _ClassVar[EventType]
    CLIPBOARD_COMMAND__POST_DELETE: _ClassVar[EventType]
    CLIPBOARD_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    CLIPBOARD_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    CLIPBOARD_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    CLIPBOARD_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    CLIPBOARD_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__POST_UPDATE: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__POST_COMMIT: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__PRE_DELETE: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__POST_DELETE: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    CLOSE_GOAL_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    CLOSE_GOAL__GOAL_ID__PRE_SEARCH: _ClassVar[EventType]
    CLOSE_GOAL__GOAL_ID__POST_SEARCH: _ClassVar[EventType]
    DIAGNOSE_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    DIAGNOSE_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    DIAGNOSE_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    DIAGNOSE_COMMAND__POST_UPDATE: _ClassVar[EventType]
    DIAGNOSE_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    DIAGNOSE_COMMAND__POST_COMMIT: _ClassVar[EventType]
    DIAGNOSE_COMMAND__PRE_DELETE: _ClassVar[EventType]
    DIAGNOSE_COMMAND__POST_DELETE: _ClassVar[EventType]
    DIAGNOSE_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    DIAGNOSE_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    DIAGNOSE_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    DIAGNOSE_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    DIAGNOSE_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    DIAGNOSE__DIAGNOSE__POST_SEARCH: _ClassVar[EventType]
    DIAGNOSE__DIAGNOSE__PRE_SEARCH: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__POST_UPDATE: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__POST_COMMIT: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__PRE_DELETE: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__POST_DELETE: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL__TITLE__PRE_SEARCH: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL__TITLE__POST_SEARCH: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL__LANGUAGE__PRE_SEARCH: _ClassVar[EventType]
    EDUCATIONAL_MATERIAL__LANGUAGE__POST_SEARCH: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__POST_UPDATE: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__POST_COMMIT: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__PRE_DELETE: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__POST_DELETE: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    FAMILY_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    FAMILY_HISTORY__FAMILY_HISTORY__PRE_SEARCH: _ClassVar[EventType]
    FAMILY_HISTORY__FAMILY_HISTORY__POST_SEARCH: _ClassVar[EventType]
    FAMILY_HISTORY__RELATIVE__PRE_SEARCH: _ClassVar[EventType]
    FAMILY_HISTORY__RELATIVE__POST_SEARCH: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__POST_UPDATE: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__POST_COMMIT: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__PRE_DELETE: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__POST_DELETE: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    FOLLOW_UP_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    FOLLOW_UP__CODING__PRE_SEARCH: _ClassVar[EventType]
    FOLLOW_UP__CODING__POST_SEARCH: _ClassVar[EventType]
    FOLLOW_UP__NOTE_TYPE__PRE_SEARCH: _ClassVar[EventType]
    FOLLOW_UP__NOTE_TYPE__POST_SEARCH: _ClassVar[EventType]
    GOAL_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    GOAL_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    GOAL_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    GOAL_COMMAND__POST_UPDATE: _ClassVar[EventType]
    GOAL_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    GOAL_COMMAND__POST_COMMIT: _ClassVar[EventType]
    GOAL_COMMAND__PRE_DELETE: _ClassVar[EventType]
    GOAL_COMMAND__POST_DELETE: _ClassVar[EventType]
    GOAL_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    GOAL_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    GOAL_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    GOAL_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    GOAL_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_UPDATE: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_COMMIT: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_DELETE: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_DELETE: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__POST_UPDATE: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__POST_COMMIT: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__PRE_DELETE: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__POST_DELETE: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    IMAGING_ORDER_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    IMAGING_ORDER__IMAGE__PRE_SEARCH: _ClassVar[EventType]
    IMAGING_ORDER__IMAGE__POST_SEARCH: _ClassVar[EventType]
    IMAGING_ORDER__INDICATIONS__PRE_SEARCH: _ClassVar[EventType]
    IMAGING_ORDER__INDICATIONS__POST_SEARCH: _ClassVar[EventType]
    IMAGING_ORDER__IMAGING_CENTER__PRE_SEARCH: _ClassVar[EventType]
    IMAGING_ORDER__IMAGING_CENTER__POST_SEARCH: _ClassVar[EventType]
    IMAGING_ORDER__ORDERING_PROVIDER__PRE_SEARCH: _ClassVar[EventType]
    IMAGING_ORDER__ORDERING_PROVIDER__POST_SEARCH: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__POST_UPDATE: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__POST_COMMIT: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__PRE_DELETE: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__POST_DELETE: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT__STATEMENT__PRE_SEARCH: _ClassVar[EventType]
    IMMUNIZATION_STATEMENT__STATEMENT__POST_SEARCH: _ClassVar[EventType]
    IMMUNIZE_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    IMMUNIZE_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    IMMUNIZE_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    IMMUNIZE_COMMAND__POST_UPDATE: _ClassVar[EventType]
    IMMUNIZE_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    IMMUNIZE_COMMAND__POST_COMMIT: _ClassVar[EventType]
    IMMUNIZE_COMMAND__PRE_DELETE: _ClassVar[EventType]
    IMMUNIZE_COMMAND__POST_DELETE: _ClassVar[EventType]
    IMMUNIZE_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    IMMUNIZE_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    IMMUNIZE_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    IMMUNIZE_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    IMMUNIZE_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    IMMUNIZE__CODING__PRE_SEARCH: _ClassVar[EventType]
    IMMUNIZE__CODING__POST_SEARCH: _ClassVar[EventType]
    IMMUNIZE__LOT_NUMBER__PRE_SEARCH: _ClassVar[EventType]
    IMMUNIZE__LOT_NUMBER__POST_SEARCH: _ClassVar[EventType]
    IMMUNIZE__GIVEN_BY__PRE_SEARCH: _ClassVar[EventType]
    IMMUNIZE__GIVEN_BY__POST_SEARCH: _ClassVar[EventType]
    INSTRUCT_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    INSTRUCT_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    INSTRUCT_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    INSTRUCT_COMMAND__POST_UPDATE: _ClassVar[EventType]
    INSTRUCT_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    INSTRUCT_COMMAND__POST_COMMIT: _ClassVar[EventType]
    INSTRUCT_COMMAND__PRE_DELETE: _ClassVar[EventType]
    INSTRUCT_COMMAND__POST_DELETE: _ClassVar[EventType]
    INSTRUCT_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    INSTRUCT_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    INSTRUCT_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    INSTRUCT_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    INSTRUCT_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    INSTRUCT__INSTRUCT__PRE_SEARCH: _ClassVar[EventType]
    INSTRUCT__INSTRUCT__POST_SEARCH: _ClassVar[EventType]
    LAB_ORDER_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    LAB_ORDER_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    LAB_ORDER_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    LAB_ORDER_COMMAND__POST_UPDATE: _ClassVar[EventType]
    LAB_ORDER_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    LAB_ORDER_COMMAND__POST_COMMIT: _ClassVar[EventType]
    LAB_ORDER_COMMAND__PRE_DELETE: _ClassVar[EventType]
    LAB_ORDER_COMMAND__POST_DELETE: _ClassVar[EventType]
    LAB_ORDER_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    LAB_ORDER_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    LAB_ORDER_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    LAB_ORDER_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    LAB_ORDER_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    LAB_ORDER__LAB_PARTNER__PRE_SEARCH: _ClassVar[EventType]
    LAB_ORDER__LAB_PARTNER__POST_SEARCH: _ClassVar[EventType]
    LAB_ORDER__TESTS__PRE_SEARCH: _ClassVar[EventType]
    LAB_ORDER__TESTS__POST_SEARCH: _ClassVar[EventType]
    LAB_ORDER__ORDERING_PROVIDER__PRE_SEARCH: _ClassVar[EventType]
    LAB_ORDER__ORDERING_PROVIDER__POST_SEARCH: _ClassVar[EventType]
    LAB_ORDER__DIAGNOSIS__PRE_SEARCH: _ClassVar[EventType]
    LAB_ORDER__DIAGNOSIS__POST_SEARCH: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__POST_UPDATE: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__POST_COMMIT: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__PRE_DELETE: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__POST_DELETE: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    MEDICAL_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    MEDICAL_HISTORY__PAST_MEDICAL_HISTORY__PRE_SEARCH: _ClassVar[EventType]
    MEDICAL_HISTORY__PAST_MEDICAL_HISTORY__POST_SEARCH: _ClassVar[EventType]
    MEDICAL_HISTORY__APPROXIMATE_START_DATE__PRE_SEARCH: _ClassVar[EventType]
    MEDICAL_HISTORY__APPROXIMATE_START_DATE__POST_SEARCH: _ClassVar[EventType]
    MEDICAL_HISTORY__APPROXIMATE_END_DATE__PRE_SEARCH: _ClassVar[EventType]
    MEDICAL_HISTORY__APPROXIMATE_END_DATE__POST_SEARCH: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__POST_UPDATE: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__POST_COMMIT: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__PRE_DELETE: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__POST_DELETE: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    MEDICATION_STATEMENT_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    PERFORM_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    PERFORM_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    PERFORM_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    PERFORM_COMMAND__POST_UPDATE: _ClassVar[EventType]
    PERFORM_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    PERFORM_COMMAND__POST_COMMIT: _ClassVar[EventType]
    PERFORM_COMMAND__PRE_DELETE: _ClassVar[EventType]
    PERFORM_COMMAND__POST_DELETE: _ClassVar[EventType]
    PERFORM_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    PERFORM_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    PERFORM_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    PERFORM_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    PERFORM_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    PERFORM__PERFORM__PRE_SEARCH: _ClassVar[EventType]
    PERFORM__PERFORM__POST_SEARCH: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__POST_UPDATE: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__POST_COMMIT: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__PRE_DELETE: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__POST_DELETE: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    PHYSICAL_EXAM_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    PHYSICAL_EXAM__QUESTIONNAIRE__PRE_SEARCH: _ClassVar[EventType]
    PHYSICAL_EXAM__QUESTIONNAIRE__POST_SEARCH: _ClassVar[EventType]
    PLAN_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    PLAN_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    PLAN_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    PLAN_COMMAND__POST_UPDATE: _ClassVar[EventType]
    PLAN_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    PLAN_COMMAND__POST_COMMIT: _ClassVar[EventType]
    PLAN_COMMAND__PRE_DELETE: _ClassVar[EventType]
    PLAN_COMMAND__POST_DELETE: _ClassVar[EventType]
    PLAN_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    PLAN_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    PLAN_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    PLAN_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    PLAN_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    PRESCRIBE_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    PRESCRIBE_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    PRESCRIBE_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    PRESCRIBE_COMMAND__POST_UPDATE: _ClassVar[EventType]
    PRESCRIBE_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    PRESCRIBE_COMMAND__POST_COMMIT: _ClassVar[EventType]
    PRESCRIBE_COMMAND__PRE_DELETE: _ClassVar[EventType]
    PRESCRIBE_COMMAND__POST_DELETE: _ClassVar[EventType]
    PRESCRIBE_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    PRESCRIBE_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    PRESCRIBE_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    PRESCRIBE_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    PRESCRIBE_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    PRESCRIBE__PRESCRIBE__POST_SEARCH: _ClassVar[EventType]
    PRESCRIBE__PRESCRIBE__PRE_SEARCH: _ClassVar[EventType]
    PRESCRIBE__INDICATIONS__PRE_SEARCH: _ClassVar[EventType]
    PRESCRIBE__INDICATIONS__POST_SEARCH: _ClassVar[EventType]
    PRESCRIBE__PHARMACY__PRE_SEARCH: _ClassVar[EventType]
    PRESCRIBE__PHARMACY__POST_SEARCH: _ClassVar[EventType]
    PRESCRIBE__SUPERVISING_PROVIDER__POST_SEARCH: _ClassVar[EventType]
    PRESCRIBE__SUPERVISING_PROVIDER__PRE_SEARCH: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__POST_UPDATE: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__POST_COMMIT: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__PRE_DELETE: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__POST_DELETE: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    QUESTIONNAIRE_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    QUESTIONNAIRE__QUESTIONNAIRE__POST_SEARCH: _ClassVar[EventType]
    QUESTIONNAIRE__QUESTIONNAIRE__PRE_SEARCH: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__POST_UPDATE: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__POST_COMMIT: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__PRE_DELETE: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__POST_DELETE: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    REASON_FOR_VISIT_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    REASON_FOR_VISIT__CODING__POST_SEARCH: _ClassVar[EventType]
    REASON_FOR_VISIT__CODING__PRE_SEARCH: _ClassVar[EventType]
    REFER_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    REFER_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    REFER_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    REFER_COMMAND__POST_UPDATE: _ClassVar[EventType]
    REFER_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    REFER_COMMAND__POST_COMMIT: _ClassVar[EventType]
    REFER_COMMAND__PRE_DELETE: _ClassVar[EventType]
    REFER_COMMAND__POST_DELETE: _ClassVar[EventType]
    REFER_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    REFER_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    REFER_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    REFER_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    REFER_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    REFER__REFER_TO__POST_SEARCH: _ClassVar[EventType]
    REFER__REFER_TO__PRE_SEARCH: _ClassVar[EventType]
    REFER__INDICATIONS__POST_SEARCH: _ClassVar[EventType]
    REFER__INDICATIONS__PRE_SEARCH: _ClassVar[EventType]
    REFER__DOCUMENTS_TO_INCLUDE__POST_SEARCH: _ClassVar[EventType]
    REFER__DOCUMENTS_TO_INCLUDE__PRE_SEARCH: _ClassVar[EventType]
    REFER__LINKED_ITEMS__POST_SEARCH: _ClassVar[EventType]
    REFER__LINKED_ITEMS_INCLUDE__PRE_SEARCH: _ClassVar[EventType]
    REFILL_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    REFILL_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    REFILL_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    REFILL_COMMAND__POST_UPDATE: _ClassVar[EventType]
    REFILL_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    REFILL_COMMAND__POST_COMMIT: _ClassVar[EventType]
    REFILL_COMMAND__PRE_DELETE: _ClassVar[EventType]
    REFILL_COMMAND__POST_DELETE: _ClassVar[EventType]
    REFILL_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    REFILL_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    REFILL_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    REFILL_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    REFILL_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    REFILL__PRESCRIBE__PRE_SEARCH: _ClassVar[EventType]
    REFILL__PRESCRIBE__POST_SEARCH: _ClassVar[EventType]
    REFILL__INDICATIONS__PRE_SEARCH: _ClassVar[EventType]
    REFILL__INDICATIONS__POST_SEARCH: _ClassVar[EventType]
    REFILL__PHARMACY__PRE_SEARCH: _ClassVar[EventType]
    REFILL__PHARMACY__POST_SEARCH: _ClassVar[EventType]
    REFILL__SUPERVISING_PROVIDER__PRE_SEARCH: _ClassVar[EventType]
    REFILL__SUPERVISING_PROVIDER__POST_SEARCH: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__POST_UPDATE: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__POST_COMMIT: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__PRE_DELETE: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__POST_DELETE: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    REMOVE_ALLERGY_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    REMOVE_ALLERGY__ALLERGY__PRE_SEARCH: _ClassVar[EventType]
    REMOVE_ALLERGY__ALLERGY__POST_SEARCH: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__POST_UPDATE: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__POST_COMMIT: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__PRE_DELETE: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__POST_DELETE: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    RESOLVE_CONDITION_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    RESOLVE_CONDITION__CONDITION__PRE_SEARCH: _ClassVar[EventType]
    RESOLVE_CONDITION__CONDITION__POST_SEARCH: _ClassVar[EventType]
    ROS_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    ROS_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    ROS_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    ROS_COMMAND__POST_UPDATE: _ClassVar[EventType]
    ROS_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    ROS_COMMAND__POST_COMMIT: _ClassVar[EventType]
    ROS_COMMAND__PRE_DELETE: _ClassVar[EventType]
    ROS_COMMAND__POST_DELETE: _ClassVar[EventType]
    ROS_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    ROS_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    ROS_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    ROS_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    ROS_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    ROS__QUESTIONNAIRE__PRE_SEARCH: _ClassVar[EventType]
    ROS__QUESTIONNAIRE__POST_SEARCH: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__POST_UPDATE: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__POST_COMMIT: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__PRE_DELETE: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__POST_DELETE: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    SNOOZE_PROTOCOL_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    SNOOZE_PROTOCOL__PROTOCOL__PRE_SEARCH: _ClassVar[EventType]
    SNOOZE_PROTOCOL__PROTOCOL__POST_SEARCH: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__POST_UPDATE: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__POST_COMMIT: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__PRE_DELETE: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__POST_DELETE: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    STOP_MEDICATION_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    STOP_MEDICATION__MEDICATION__PRE_SEARCH: _ClassVar[EventType]
    STOP_MEDICATION__MEDICATION__POST_SEARCH: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__POST_UPDATE: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__POST_COMMIT: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__PRE_DELETE: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__POST_DELETE: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT__QUESTIONNAIRE__PRE_SEARCH: _ClassVar[EventType]
    STRUCTURED_ASSESSMENT__QUESTIONNAIRE__POST_SEARCH: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__POST_UPDATE: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__POST_COMMIT: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__PRE_DELETE: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__POST_DELETE: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    SURGICAL_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    SURGICAL_HISTORY__PAST_SURGICAL_HISTORY__PRE_SEARCH: _ClassVar[EventType]
    SURGICAL_HISTORY__PAST_SURGICAL_HISTORY__POST_SEARCH: _ClassVar[EventType]
    TASK_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    TASK_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    TASK_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    TASK_COMMAND__POST_UPDATE: _ClassVar[EventType]
    TASK_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    TASK_COMMAND__POST_COMMIT: _ClassVar[EventType]
    TASK_COMMAND__PRE_DELETE: _ClassVar[EventType]
    TASK_COMMAND__POST_DELETE: _ClassVar[EventType]
    TASK_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    TASK_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    TASK_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    TASK_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    TASK_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    TASK__ASSIGN_TO__PRE_SEARCH: _ClassVar[EventType]
    TASK__ASSIGN_TO__POST_SEARCH: _ClassVar[EventType]
    TASK__LABELS__PRE_SEARCH: _ClassVar[EventType]
    TASK__LABELS__POST_SEARCH: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__POST_UPDATE: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__POST_COMMIT: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__PRE_DELETE: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__POST_DELETE: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    UPDATE_DIAGNOSIS_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    UPDATE_DIAGNOSIS__CONDITION__PRE_SEARCH: _ClassVar[EventType]
    UPDATE_DIAGNOSIS__CONDITION__POST_SEARCH: _ClassVar[EventType]
    UPDATE_DIAGNOSIS__NEW_CONDITION__PRE_SEARCH: _ClassVar[EventType]
    UPDATE_DIAGNOSIS__NEW_CONDITION__POST_SEARCH: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__POST_UPDATE: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__POST_COMMIT: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__PRE_DELETE: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__POST_DELETE: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    UPDATE_GOAL_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    UPDATE_GOAL__GOAL_STATEMENT__PRE_SEARCH: _ClassVar[EventType]
    UPDATE_GOAL__GOAL_STATEMENT__POST_SEARCH: _ClassVar[EventType]
    VITALS_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    VITALS_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    VITALS_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    VITALS_COMMAND__POST_UPDATE: _ClassVar[EventType]
    VITALS_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    VITALS_COMMAND__POST_COMMIT: _ClassVar[EventType]
    VITALS_COMMAND__PRE_DELETE: _ClassVar[EventType]
    VITALS_COMMAND__POST_DELETE: _ClassVar[EventType]
    VITALS_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    VITALS_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    VITALS_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    VITALS_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    VITALS_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__POST_UPDATE: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__POST_COMMIT: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__PRE_DELETE: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__POST_DELETE: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    ASSESS_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    ASSESS_CODING_GAP__DIAGNOSE__PRE_SEARCH: _ClassVar[EventType]
    ASSESS_CODING_GAP__DIAGNOSE__POST_SEARCH: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__POST_UPDATE: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__POST_COMMIT: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__PRE_DELETE: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__POST_DELETE: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    CREATE_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    CREATE_CODING_GAP__DIAGNOSE__PRE_SEARCH: _ClassVar[EventType]
    CREATE_CODING_GAP__DIAGNOSE__POST_SEARCH: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__POST_UPDATE: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__POST_COMMIT: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__PRE_DELETE: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__POST_DELETE: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    VALIDATE_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__POST_UPDATE: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__POST_COMMIT: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__PRE_DELETE: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__POST_DELETE: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    DEFER_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__PRE_ORIGINATE: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__POST_ORIGINATE: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__PRE_UPDATE: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__POST_UPDATE: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__PRE_COMMIT: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__POST_COMMIT: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__PRE_DELETE: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__POST_DELETE: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__PRE_ENTER_IN_ERROR: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__POST_ENTER_IN_ERROR: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__PRE_EXECUTE_ACTION: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__POST_EXECUTE_ACTION: _ClassVar[EventType]
    CHANGE_MEDICATION_COMMAND__POST_INSERTED_INTO_NOTE: _ClassVar[EventType]
    CHANGE_MEDICATION__MEDICATION__PRE_SEARCH: _ClassVar[EventType]
    CHANGE_MEDICATION__MEDICATION__POST_SEARCH: _ClassVar[EventType]
    SHOW_NOTE_HEADER_BUTTON: _ClassVar[EventType]
    SHOW_NOTE_FOOTER_BUTTON: _ClassVar[EventType]
    ACTION_BUTTON_CLICKED: _ClassVar[EventType]
    PATIENT_CHART__CONDITIONS: _ClassVar[EventType]
    PATIENT_CHART_SUMMARY__SECTION_CONFIGURATION: _ClassVar[EventType]
    PATIENT_PROFILE__SECTION_CONFIGURATION: _ClassVar[EventType]
    PATIENT_PROFILE__ADD_PHARMACY__POST_SEARCH: _ClassVar[EventType]
    CLAIM__CONDITIONS: _ClassVar[EventType]
    PLUGIN_CREATED: _ClassVar[EventType]
    PLUGIN_UPDATED: _ClassVar[EventType]
    APPLICATION__ON_OPEN: _ClassVar[EventType]
    PATIENT_PORTAL__GET_FORMS: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENT_CANCELED: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENT_RESCHEDULED: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENT_CAN_BE_CANCELED: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENT_CAN_BE_RESCHEDULED: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENTS__SLOTS__POST_SEARCH: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__PRE_SEARCH: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__POST_SEARCH: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__PRE_SEARCH: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__POST_SEARCH: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__PRE_SEARCH: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__POST_SEARCH: _ClassVar[EventType]
    PATIENT_PORTAL__APPOINTMENT_CAN_SHOW_MEETING_LINK: _ClassVar[EventType]
    PATIENT_PORTAL__GET_APPLICATION_CONFIGURATION: _ClassVar[EventType]
    PATIENT_PORTAL__MENU_CONFIGURATION: _ClassVar[EventType]
    PATIENT_PORTAL__WIDGET_CONFIGURATION: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_SOCIAL_DETERMINANTS_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_GOALS_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_CONDITIONS_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_MEDICATIONS_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_ALLERGIES_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_CARE_TEAMS_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_VITALS_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_IMMUNIZATIONS_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_SURGICAL_HISTORY_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_FAMILY_HISTORY_SECTION_BUTTON: _ClassVar[EventType]
    SHOW_CHART_SUMMARY_CODING_GAPS_SECTION_BUTTON: _ClassVar[EventType]
    SIMPLE_API_AUTHENTICATE: _ClassVar[EventType]
    SIMPLE_API_REQUEST: _ClassVar[EventType]
    SIMPLE_API_WEBSOCKET_AUTHENTICATE: _ClassVar[EventType]
    PATIENT_METADATA__GET_ADDITIONAL_FIELDS: _ClassVar[EventType]
    PATIENT_EXTERNAL_IDENTIFIER_CREATED: _ClassVar[EventType]
    PATIENT_EXTERNAL_IDENTIFIER_UPDATED: _ClassVar[EventType]
    PATIENT_EXTERNAL_IDENTIFIER_DELETED: _ClassVar[EventType]
UNKNOWN: EventType
ALLERGY_INTOLERANCE_CREATED: EventType
ALLERGY_INTOLERANCE_UPDATED: EventType
APPOINTMENT_CANCELED: EventType
APPOINTMENT_CHECKED_IN: EventType
APPOINTMENT_CREATED: EventType
APPOINTMENT_NO_SHOWED: EventType
APPOINTMENT_RESCHEDULED: EventType
APPOINTMENT_RESTORED: EventType
APPOINTMENT_UPDATED: EventType
BILLING_LINE_ITEM_CREATED: EventType
BILLING_LINE_ITEM_UPDATED: EventType
CONDITION_ASSESSED: EventType
CONDITION_CREATED: EventType
CONDITION_RESOLVED: EventType
CONDITION_UPDATED: EventType
CONSENT_CREATED: EventType
CONSENT_DELETED: EventType
CONSENT_UPDATED: EventType
COVERAGE_CREATED: EventType
COVERAGE_UPDATED: EventType
ENCOUNTER_CREATED: EventType
ENCOUNTER_UPDATED: EventType
IMAGING_REPORT_CREATED: EventType
IMAGING_REPORT_UPDATED: EventType
IMMUNIZATION_CREATED: EventType
IMMUNIZATION_STATEMENT_CREATED: EventType
IMMUNIZATION_STATEMENT_UPDATED: EventType
IMMUNIZATION_UPDATED: EventType
INSTRUCTION_CREATED: EventType
INSTRUCTION_UPDATED: EventType
INTERVIEW_CREATED: EventType
INTERVIEW_UPDATED: EventType
LAB_ORDER_CREATED: EventType
LAB_ORDER_UPDATED: EventType
LAB_REPORT_CREATED: EventType
LAB_REPORT_UPDATED: EventType
MEDICATION_LIST_ITEM_CREATED: EventType
MEDICATION_LIST_ITEM_UPDATED: EventType
MESSAGE_CREATED: EventType
PATIENT_CREATED: EventType
PATIENT_UPDATED: EventType
PRESCRIPTION_CREATED: EventType
PRESCRIPTION_UPDATED: EventType
REFERRAL_REPORT_CREATED: EventType
REFERRAL_REPORT_UPDATED: EventType
TASK_COMMENT_CREATED: EventType
TASK_CREATED: EventType
TASK_LABELS_ADJUSTED: EventType
TASK_UPDATED: EventType
VITAL_SIGN_CREATED: EventType
VITAL_SIGN_UPDATED: EventType
CRON: EventType
CARE_TEAM_MEMBERSHIP_CREATED: EventType
CARE_TEAM_MEMBERSHIP_UPDATED: EventType
CARE_TEAM_MEMBERSHIP_DELETED: EventType
NOTE_STATE_CHANGE_EVENT_CREATED: EventType
NOTE_STATE_CHANGE_EVENT_UPDATED: EventType
PATIENT_ADDRESS_CREATED: EventType
PATIENT_ADDRESS_UPDATED: EventType
PATIENT_ADDRESS_DELETED: EventType
PATIENT_CONTACT_PERSON_CREATED: EventType
PATIENT_CONTACT_PERSON_UPDATED: EventType
PATIENT_CONTACT_PERSON_DELETED: EventType
PATIENT_CONTACT_POINT_CREATED: EventType
PATIENT_CONTACT_POINT_UPDATED: EventType
PATIENT_CONTACT_POINT_DELETED: EventType
PROTOCOL_OVERRIDE_CREATED: EventType
PROTOCOL_OVERRIDE_UPDATED: EventType
PROTOCOL_OVERRIDE_DELETED: EventType
TASK_COMMENT_UPDATED: EventType
TASK_COMMENT_DELETED: EventType
DEVICE_CREATED: EventType
DEVICE_UPDATED: EventType
OBSERVATION_CREATED: EventType
OBSERVATION_UPDATED: EventType
DETECTED_ISSUE_CREATED: EventType
DETECTED_ISSUE_UPDATED: EventType
TASK_CLOSED: EventType
TASK_COMPLETED: EventType
DETECTED_ISSUE_EVIDENCE_CREATED: EventType
DETECTED_ISSUE_EVIDENCE_UPDATED: EventType
PRE_COMMAND_ORIGINATE: EventType
POST_COMMAND_ORIGINATE: EventType
PRE_COMMAND_UPDATE: EventType
POST_COMMAND_UPDATE: EventType
PRE_COMMAND_COMMIT: EventType
POST_COMMAND_COMMIT: EventType
PRE_COMMAND_DELETE: EventType
POST_COMMAND_DELETE: EventType
PRE_COMMAND_ENTER_IN_ERROR: EventType
POST_COMMAND_ENTER_IN_ERROR: EventType
PRE_COMMAND_EXECUTE_ACTION: EventType
POST_COMMAND_EXECUTE_ACTION: EventType
POST_COMMAND_INSERTED_INTO_NOTE: EventType
ASSESS_COMMAND__CONDITION_SELECTED: EventType
MEDICATION_STATEMENT__MEDICATION__PRE_SEARCH: EventType
MEDICATION_STATEMENT__MEDICATION__POST_SEARCH: EventType
MEDICATION_STATEMENT__MEDICATION__SELECTED: EventType
ADJUST_PRESCRIPTION_COMMAND__PRE_ORIGINATE: EventType
ADJUST_PRESCRIPTION_COMMAND__POST_ORIGINATE: EventType
ADJUST_PRESCRIPTION_COMMAND__PRE_UPDATE: EventType
ADJUST_PRESCRIPTION_COMMAND__POST_UPDATE: EventType
ADJUST_PRESCRIPTION_COMMAND__PRE_COMMIT: EventType
ADJUST_PRESCRIPTION_COMMAND__POST_COMMIT: EventType
ADJUST_PRESCRIPTION_COMMAND__PRE_DELETE: EventType
ADJUST_PRESCRIPTION_COMMAND__POST_DELETE: EventType
ADJUST_PRESCRIPTION_COMMAND__PRE_ENTER_IN_ERROR: EventType
ADJUST_PRESCRIPTION_COMMAND__POST_ENTER_IN_ERROR: EventType
ADJUST_PRESCRIPTION_COMMAND__PRE_EXECUTE_ACTION: EventType
ADJUST_PRESCRIPTION_COMMAND__POST_EXECUTE_ACTION: EventType
ADJUST_PRESCRIPTION_COMMAND__POST_INSERTED_INTO_NOTE: EventType
ADJUST_PRESCRIPTION__PRESCRIBE__POST_SEARCH: EventType
ADJUST_PRESCRIPTION__PRESCRIBE__PRE_SEARCH: EventType
ADJUST_PRESCRIPTION__INDICATIONS__PRE_SEARCH: EventType
ADJUST_PRESCRIPTION__INDICATIONS__POST_SEARCH: EventType
ADJUST_PRESCRIPTION__PHARMACY__PRE_SEARCH: EventType
ADJUST_PRESCRIPTION__PHARMACY__POST_SEARCH: EventType
ADJUST_PRESCRIPTION__CHANGE_MEDICATION_TO__PRE_SEARCH: EventType
ADJUST_PRESCRIPTION__CHANGE_MEDICATION_TO__POST_SEARCH: EventType
ADJUST_PRESCRIPTION__SUPERVISING_PROVIDER__PRE_SEARCH: EventType
ADJUST_PRESCRIPTION__SUPERVISING_PROVIDER__POST_SEARCH: EventType
ALLERGY_COMMAND__PRE_ORIGINATE: EventType
ALLERGY_COMMAND__POST_ORIGINATE: EventType
ALLERGY_COMMAND__PRE_UPDATE: EventType
ALLERGY_COMMAND__POST_UPDATE: EventType
ALLERGY_COMMAND__PRE_COMMIT: EventType
ALLERGY_COMMAND__POST_COMMIT: EventType
ALLERGY_COMMAND__PRE_DELETE: EventType
ALLERGY_COMMAND__POST_DELETE: EventType
ALLERGY_COMMAND__PRE_ENTER_IN_ERROR: EventType
ALLERGY_COMMAND__POST_ENTER_IN_ERROR: EventType
ALLERGY_COMMAND__PRE_EXECUTE_ACTION: EventType
ALLERGY_COMMAND__POST_EXECUTE_ACTION: EventType
ALLERGY_COMMAND__POST_INSERTED_INTO_NOTE: EventType
ALLERGY__ALLERGY__PRE_SEARCH: EventType
ALLERGY__ALLERGY__POST_SEARCH: EventType
ASSESS_COMMAND__PRE_ORIGINATE: EventType
ASSESS_COMMAND__POST_ORIGINATE: EventType
ASSESS_COMMAND__PRE_UPDATE: EventType
ASSESS_COMMAND__POST_UPDATE: EventType
ASSESS_COMMAND__PRE_COMMIT: EventType
ASSESS_COMMAND__POST_COMMIT: EventType
ASSESS_COMMAND__PRE_DELETE: EventType
ASSESS_COMMAND__POST_DELETE: EventType
ASSESS_COMMAND__PRE_ENTER_IN_ERROR: EventType
ASSESS_COMMAND__POST_ENTER_IN_ERROR: EventType
ASSESS_COMMAND__PRE_EXECUTE_ACTION: EventType
ASSESS_COMMAND__POST_EXECUTE_ACTION: EventType
ASSESS_COMMAND__POST_INSERTED_INTO_NOTE: EventType
ASSESS__CONDITION__POST_SEARCH: EventType
ASSESS__CONDITION__PRE_SEARCH: EventType
CANCEL_PRESCRIPTION_COMMAND__PRE_ORIGINATE: EventType
CANCEL_PRESCRIPTION_COMMAND__POST_ORIGINATE: EventType
CANCEL_PRESCRIPTION_COMMAND__PRE_UPDATE: EventType
CANCEL_PRESCRIPTION_COMMAND__POST_UPDATE: EventType
CANCEL_PRESCRIPTION_COMMAND__PRE_COMMIT: EventType
CANCEL_PRESCRIPTION_COMMAND__POST_COMMIT: EventType
CANCEL_PRESCRIPTION_COMMAND__PRE_DELETE: EventType
CANCEL_PRESCRIPTION_COMMAND__POST_DELETE: EventType
CANCEL_PRESCRIPTION_COMMAND__PRE_ENTER_IN_ERROR: EventType
CANCEL_PRESCRIPTION_COMMAND__POST_ENTER_IN_ERROR: EventType
CANCEL_PRESCRIPTION_COMMAND__PRE_EXECUTE_ACTION: EventType
CANCEL_PRESCRIPTION_COMMAND__POST_EXECUTE_ACTION: EventType
CANCEL_PRESCRIPTION__SELECTED_PRESCRIPTION__PRE_SEARCH: EventType
CANCEL_PRESCRIPTION__SELECTED_PRESCRIPTION__POST_SEARCH: EventType
CHART_SECTION_REVIEW_COMMAND__PRE_ORIGINATE: EventType
CHART_SECTION_REVIEW_COMMAND__POST_ORIGINATE: EventType
CHART_SECTION_REVIEW_COMMAND__PRE_ENTER_IN_ERROR: EventType
CHART_SECTION_REVIEW_COMMAND__POST_ENTER_IN_ERROR: EventType
CHART_SECTION_REVIEW_COMMAND__PRE_EXECUTE_ACTION: EventType
CHART_SECTION_REVIEW_COMMAND__POST_EXECUTE_ACTION: EventType
CLIPBOARD_COMMAND__PRE_ORIGINATE: EventType
CLIPBOARD_COMMAND__POST_ORIGINATE: EventType
CLIPBOARD_COMMAND__PRE_UPDATE: EventType
CLIPBOARD_COMMAND__POST_UPDATE: EventType
CLIPBOARD_COMMAND__PRE_COMMIT: EventType
CLIPBOARD_COMMAND__POST_COMMIT: EventType
CLIPBOARD_COMMAND__PRE_DELETE: EventType
CLIPBOARD_COMMAND__POST_DELETE: EventType
CLIPBOARD_COMMAND__PRE_ENTER_IN_ERROR: EventType
CLIPBOARD_COMMAND__POST_ENTER_IN_ERROR: EventType
CLIPBOARD_COMMAND__PRE_EXECUTE_ACTION: EventType
CLIPBOARD_COMMAND__POST_EXECUTE_ACTION: EventType
CLIPBOARD_COMMAND__POST_INSERTED_INTO_NOTE: EventType
CLOSE_GOAL_COMMAND__PRE_ORIGINATE: EventType
CLOSE_GOAL_COMMAND__POST_ORIGINATE: EventType
CLOSE_GOAL_COMMAND__PRE_UPDATE: EventType
CLOSE_GOAL_COMMAND__POST_UPDATE: EventType
CLOSE_GOAL_COMMAND__PRE_COMMIT: EventType
CLOSE_GOAL_COMMAND__POST_COMMIT: EventType
CLOSE_GOAL_COMMAND__PRE_DELETE: EventType
CLOSE_GOAL_COMMAND__POST_DELETE: EventType
CLOSE_GOAL_COMMAND__PRE_ENTER_IN_ERROR: EventType
CLOSE_GOAL_COMMAND__POST_ENTER_IN_ERROR: EventType
CLOSE_GOAL_COMMAND__PRE_EXECUTE_ACTION: EventType
CLOSE_GOAL_COMMAND__POST_EXECUTE_ACTION: EventType
CLOSE_GOAL_COMMAND__POST_INSERTED_INTO_NOTE: EventType
CLOSE_GOAL__GOAL_ID__PRE_SEARCH: EventType
CLOSE_GOAL__GOAL_ID__POST_SEARCH: EventType
DIAGNOSE_COMMAND__PRE_ORIGINATE: EventType
DIAGNOSE_COMMAND__POST_ORIGINATE: EventType
DIAGNOSE_COMMAND__PRE_UPDATE: EventType
DIAGNOSE_COMMAND__POST_UPDATE: EventType
DIAGNOSE_COMMAND__PRE_COMMIT: EventType
DIAGNOSE_COMMAND__POST_COMMIT: EventType
DIAGNOSE_COMMAND__PRE_DELETE: EventType
DIAGNOSE_COMMAND__POST_DELETE: EventType
DIAGNOSE_COMMAND__PRE_ENTER_IN_ERROR: EventType
DIAGNOSE_COMMAND__POST_ENTER_IN_ERROR: EventType
DIAGNOSE_COMMAND__PRE_EXECUTE_ACTION: EventType
DIAGNOSE_COMMAND__POST_EXECUTE_ACTION: EventType
DIAGNOSE_COMMAND__POST_INSERTED_INTO_NOTE: EventType
DIAGNOSE__DIAGNOSE__POST_SEARCH: EventType
DIAGNOSE__DIAGNOSE__PRE_SEARCH: EventType
EDUCATIONAL_MATERIAL_COMMAND__PRE_ORIGINATE: EventType
EDUCATIONAL_MATERIAL_COMMAND__POST_ORIGINATE: EventType
EDUCATIONAL_MATERIAL_COMMAND__PRE_UPDATE: EventType
EDUCATIONAL_MATERIAL_COMMAND__POST_UPDATE: EventType
EDUCATIONAL_MATERIAL_COMMAND__PRE_COMMIT: EventType
EDUCATIONAL_MATERIAL_COMMAND__POST_COMMIT: EventType
EDUCATIONAL_MATERIAL_COMMAND__PRE_DELETE: EventType
EDUCATIONAL_MATERIAL_COMMAND__POST_DELETE: EventType
EDUCATIONAL_MATERIAL_COMMAND__PRE_ENTER_IN_ERROR: EventType
EDUCATIONAL_MATERIAL_COMMAND__POST_ENTER_IN_ERROR: EventType
EDUCATIONAL_MATERIAL_COMMAND__PRE_EXECUTE_ACTION: EventType
EDUCATIONAL_MATERIAL_COMMAND__POST_EXECUTE_ACTION: EventType
EDUCATIONAL_MATERIAL_COMMAND__POST_INSERTED_INTO_NOTE: EventType
EDUCATIONAL_MATERIAL__TITLE__PRE_SEARCH: EventType
EDUCATIONAL_MATERIAL__TITLE__POST_SEARCH: EventType
EDUCATIONAL_MATERIAL__LANGUAGE__PRE_SEARCH: EventType
EDUCATIONAL_MATERIAL__LANGUAGE__POST_SEARCH: EventType
FAMILY_HISTORY_COMMAND__PRE_ORIGINATE: EventType
FAMILY_HISTORY_COMMAND__POST_ORIGINATE: EventType
FAMILY_HISTORY_COMMAND__PRE_UPDATE: EventType
FAMILY_HISTORY_COMMAND__POST_UPDATE: EventType
FAMILY_HISTORY_COMMAND__PRE_COMMIT: EventType
FAMILY_HISTORY_COMMAND__POST_COMMIT: EventType
FAMILY_HISTORY_COMMAND__PRE_DELETE: EventType
FAMILY_HISTORY_COMMAND__POST_DELETE: EventType
FAMILY_HISTORY_COMMAND__PRE_ENTER_IN_ERROR: EventType
FAMILY_HISTORY_COMMAND__POST_ENTER_IN_ERROR: EventType
FAMILY_HISTORY_COMMAND__PRE_EXECUTE_ACTION: EventType
FAMILY_HISTORY_COMMAND__POST_EXECUTE_ACTION: EventType
FAMILY_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE: EventType
FAMILY_HISTORY__FAMILY_HISTORY__PRE_SEARCH: EventType
FAMILY_HISTORY__FAMILY_HISTORY__POST_SEARCH: EventType
FAMILY_HISTORY__RELATIVE__PRE_SEARCH: EventType
FAMILY_HISTORY__RELATIVE__POST_SEARCH: EventType
FOLLOW_UP_COMMAND__PRE_ORIGINATE: EventType
FOLLOW_UP_COMMAND__POST_ORIGINATE: EventType
FOLLOW_UP_COMMAND__PRE_UPDATE: EventType
FOLLOW_UP_COMMAND__POST_UPDATE: EventType
FOLLOW_UP_COMMAND__PRE_COMMIT: EventType
FOLLOW_UP_COMMAND__POST_COMMIT: EventType
FOLLOW_UP_COMMAND__PRE_DELETE: EventType
FOLLOW_UP_COMMAND__POST_DELETE: EventType
FOLLOW_UP_COMMAND__PRE_ENTER_IN_ERROR: EventType
FOLLOW_UP_COMMAND__POST_ENTER_IN_ERROR: EventType
FOLLOW_UP_COMMAND__PRE_EXECUTE_ACTION: EventType
FOLLOW_UP_COMMAND__POST_EXECUTE_ACTION: EventType
FOLLOW_UP_COMMAND__POST_INSERTED_INTO_NOTE: EventType
FOLLOW_UP__CODING__PRE_SEARCH: EventType
FOLLOW_UP__CODING__POST_SEARCH: EventType
FOLLOW_UP__NOTE_TYPE__PRE_SEARCH: EventType
FOLLOW_UP__NOTE_TYPE__POST_SEARCH: EventType
GOAL_COMMAND__PRE_ORIGINATE: EventType
GOAL_COMMAND__POST_ORIGINATE: EventType
GOAL_COMMAND__PRE_UPDATE: EventType
GOAL_COMMAND__POST_UPDATE: EventType
GOAL_COMMAND__PRE_COMMIT: EventType
GOAL_COMMAND__POST_COMMIT: EventType
GOAL_COMMAND__PRE_DELETE: EventType
GOAL_COMMAND__POST_DELETE: EventType
GOAL_COMMAND__PRE_ENTER_IN_ERROR: EventType
GOAL_COMMAND__POST_ENTER_IN_ERROR: EventType
GOAL_COMMAND__PRE_EXECUTE_ACTION: EventType
GOAL_COMMAND__POST_EXECUTE_ACTION: EventType
GOAL_COMMAND__POST_INSERTED_INTO_NOTE: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_ORIGINATE: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_ORIGINATE: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_UPDATE: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_UPDATE: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_COMMIT: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_COMMIT: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_DELETE: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_DELETE: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_ENTER_IN_ERROR: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_ENTER_IN_ERROR: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__PRE_EXECUTE_ACTION: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_EXECUTE_ACTION: EventType
HISTORY_OF_PRESENT_ILLNESS_COMMAND__POST_INSERTED_INTO_NOTE: EventType
IMAGING_ORDER_COMMAND__PRE_ORIGINATE: EventType
IMAGING_ORDER_COMMAND__POST_ORIGINATE: EventType
IMAGING_ORDER_COMMAND__PRE_UPDATE: EventType
IMAGING_ORDER_COMMAND__POST_UPDATE: EventType
IMAGING_ORDER_COMMAND__PRE_COMMIT: EventType
IMAGING_ORDER_COMMAND__POST_COMMIT: EventType
IMAGING_ORDER_COMMAND__PRE_DELETE: EventType
IMAGING_ORDER_COMMAND__POST_DELETE: EventType
IMAGING_ORDER_COMMAND__PRE_ENTER_IN_ERROR: EventType
IMAGING_ORDER_COMMAND__POST_ENTER_IN_ERROR: EventType
IMAGING_ORDER_COMMAND__PRE_EXECUTE_ACTION: EventType
IMAGING_ORDER_COMMAND__POST_EXECUTE_ACTION: EventType
IMAGING_ORDER_COMMAND__POST_INSERTED_INTO_NOTE: EventType
IMAGING_ORDER__IMAGE__PRE_SEARCH: EventType
IMAGING_ORDER__IMAGE__POST_SEARCH: EventType
IMAGING_ORDER__INDICATIONS__PRE_SEARCH: EventType
IMAGING_ORDER__INDICATIONS__POST_SEARCH: EventType
IMAGING_ORDER__IMAGING_CENTER__PRE_SEARCH: EventType
IMAGING_ORDER__IMAGING_CENTER__POST_SEARCH: EventType
IMAGING_ORDER__ORDERING_PROVIDER__PRE_SEARCH: EventType
IMAGING_ORDER__ORDERING_PROVIDER__POST_SEARCH: EventType
IMMUNIZATION_STATEMENT_COMMAND__PRE_ORIGINATE: EventType
IMMUNIZATION_STATEMENT_COMMAND__POST_ORIGINATE: EventType
IMMUNIZATION_STATEMENT_COMMAND__PRE_UPDATE: EventType
IMMUNIZATION_STATEMENT_COMMAND__POST_UPDATE: EventType
IMMUNIZATION_STATEMENT_COMMAND__PRE_COMMIT: EventType
IMMUNIZATION_STATEMENT_COMMAND__POST_COMMIT: EventType
IMMUNIZATION_STATEMENT_COMMAND__PRE_DELETE: EventType
IMMUNIZATION_STATEMENT_COMMAND__POST_DELETE: EventType
IMMUNIZATION_STATEMENT_COMMAND__PRE_ENTER_IN_ERROR: EventType
IMMUNIZATION_STATEMENT_COMMAND__POST_ENTER_IN_ERROR: EventType
IMMUNIZATION_STATEMENT_COMMAND__PRE_EXECUTE_ACTION: EventType
IMMUNIZATION_STATEMENT_COMMAND__POST_EXECUTE_ACTION: EventType
IMMUNIZATION_STATEMENT_COMMAND__POST_INSERTED_INTO_NOTE: EventType
IMMUNIZATION_STATEMENT__STATEMENT__PRE_SEARCH: EventType
IMMUNIZATION_STATEMENT__STATEMENT__POST_SEARCH: EventType
IMMUNIZE_COMMAND__PRE_ORIGINATE: EventType
IMMUNIZE_COMMAND__POST_ORIGINATE: EventType
IMMUNIZE_COMMAND__PRE_UPDATE: EventType
IMMUNIZE_COMMAND__POST_UPDATE: EventType
IMMUNIZE_COMMAND__PRE_COMMIT: EventType
IMMUNIZE_COMMAND__POST_COMMIT: EventType
IMMUNIZE_COMMAND__PRE_DELETE: EventType
IMMUNIZE_COMMAND__POST_DELETE: EventType
IMMUNIZE_COMMAND__PRE_ENTER_IN_ERROR: EventType
IMMUNIZE_COMMAND__POST_ENTER_IN_ERROR: EventType
IMMUNIZE_COMMAND__PRE_EXECUTE_ACTION: EventType
IMMUNIZE_COMMAND__POST_EXECUTE_ACTION: EventType
IMMUNIZE_COMMAND__POST_INSERTED_INTO_NOTE: EventType
IMMUNIZE__CODING__PRE_SEARCH: EventType
IMMUNIZE__CODING__POST_SEARCH: EventType
IMMUNIZE__LOT_NUMBER__PRE_SEARCH: EventType
IMMUNIZE__LOT_NUMBER__POST_SEARCH: EventType
IMMUNIZE__GIVEN_BY__PRE_SEARCH: EventType
IMMUNIZE__GIVEN_BY__POST_SEARCH: EventType
INSTRUCT_COMMAND__PRE_ORIGINATE: EventType
INSTRUCT_COMMAND__POST_ORIGINATE: EventType
INSTRUCT_COMMAND__PRE_UPDATE: EventType
INSTRUCT_COMMAND__POST_UPDATE: EventType
INSTRUCT_COMMAND__PRE_COMMIT: EventType
INSTRUCT_COMMAND__POST_COMMIT: EventType
INSTRUCT_COMMAND__PRE_DELETE: EventType
INSTRUCT_COMMAND__POST_DELETE: EventType
INSTRUCT_COMMAND__PRE_ENTER_IN_ERROR: EventType
INSTRUCT_COMMAND__POST_ENTER_IN_ERROR: EventType
INSTRUCT_COMMAND__PRE_EXECUTE_ACTION: EventType
INSTRUCT_COMMAND__POST_EXECUTE_ACTION: EventType
INSTRUCT_COMMAND__POST_INSERTED_INTO_NOTE: EventType
INSTRUCT__INSTRUCT__PRE_SEARCH: EventType
INSTRUCT__INSTRUCT__POST_SEARCH: EventType
LAB_ORDER_COMMAND__PRE_ORIGINATE: EventType
LAB_ORDER_COMMAND__POST_ORIGINATE: EventType
LAB_ORDER_COMMAND__PRE_UPDATE: EventType
LAB_ORDER_COMMAND__POST_UPDATE: EventType
LAB_ORDER_COMMAND__PRE_COMMIT: EventType
LAB_ORDER_COMMAND__POST_COMMIT: EventType
LAB_ORDER_COMMAND__PRE_DELETE: EventType
LAB_ORDER_COMMAND__POST_DELETE: EventType
LAB_ORDER_COMMAND__PRE_ENTER_IN_ERROR: EventType
LAB_ORDER_COMMAND__POST_ENTER_IN_ERROR: EventType
LAB_ORDER_COMMAND__PRE_EXECUTE_ACTION: EventType
LAB_ORDER_COMMAND__POST_EXECUTE_ACTION: EventType
LAB_ORDER_COMMAND__POST_INSERTED_INTO_NOTE: EventType
LAB_ORDER__LAB_PARTNER__PRE_SEARCH: EventType
LAB_ORDER__LAB_PARTNER__POST_SEARCH: EventType
LAB_ORDER__TESTS__PRE_SEARCH: EventType
LAB_ORDER__TESTS__POST_SEARCH: EventType
LAB_ORDER__ORDERING_PROVIDER__PRE_SEARCH: EventType
LAB_ORDER__ORDERING_PROVIDER__POST_SEARCH: EventType
LAB_ORDER__DIAGNOSIS__PRE_SEARCH: EventType
LAB_ORDER__DIAGNOSIS__POST_SEARCH: EventType
MEDICAL_HISTORY_COMMAND__PRE_ORIGINATE: EventType
MEDICAL_HISTORY_COMMAND__POST_ORIGINATE: EventType
MEDICAL_HISTORY_COMMAND__PRE_UPDATE: EventType
MEDICAL_HISTORY_COMMAND__POST_UPDATE: EventType
MEDICAL_HISTORY_COMMAND__PRE_COMMIT: EventType
MEDICAL_HISTORY_COMMAND__POST_COMMIT: EventType
MEDICAL_HISTORY_COMMAND__PRE_DELETE: EventType
MEDICAL_HISTORY_COMMAND__POST_DELETE: EventType
MEDICAL_HISTORY_COMMAND__PRE_ENTER_IN_ERROR: EventType
MEDICAL_HISTORY_COMMAND__POST_ENTER_IN_ERROR: EventType
MEDICAL_HISTORY_COMMAND__PRE_EXECUTE_ACTION: EventType
MEDICAL_HISTORY_COMMAND__POST_EXECUTE_ACTION: EventType
MEDICAL_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE: EventType
MEDICAL_HISTORY__PAST_MEDICAL_HISTORY__PRE_SEARCH: EventType
MEDICAL_HISTORY__PAST_MEDICAL_HISTORY__POST_SEARCH: EventType
MEDICAL_HISTORY__APPROXIMATE_START_DATE__PRE_SEARCH: EventType
MEDICAL_HISTORY__APPROXIMATE_START_DATE__POST_SEARCH: EventType
MEDICAL_HISTORY__APPROXIMATE_END_DATE__PRE_SEARCH: EventType
MEDICAL_HISTORY__APPROXIMATE_END_DATE__POST_SEARCH: EventType
MEDICATION_STATEMENT_COMMAND__PRE_ORIGINATE: EventType
MEDICATION_STATEMENT_COMMAND__POST_ORIGINATE: EventType
MEDICATION_STATEMENT_COMMAND__PRE_UPDATE: EventType
MEDICATION_STATEMENT_COMMAND__POST_UPDATE: EventType
MEDICATION_STATEMENT_COMMAND__PRE_COMMIT: EventType
MEDICATION_STATEMENT_COMMAND__POST_COMMIT: EventType
MEDICATION_STATEMENT_COMMAND__PRE_DELETE: EventType
MEDICATION_STATEMENT_COMMAND__POST_DELETE: EventType
MEDICATION_STATEMENT_COMMAND__PRE_ENTER_IN_ERROR: EventType
MEDICATION_STATEMENT_COMMAND__POST_ENTER_IN_ERROR: EventType
MEDICATION_STATEMENT_COMMAND__PRE_EXECUTE_ACTION: EventType
MEDICATION_STATEMENT_COMMAND__POST_EXECUTE_ACTION: EventType
MEDICATION_STATEMENT_COMMAND__POST_INSERTED_INTO_NOTE: EventType
PERFORM_COMMAND__PRE_ORIGINATE: EventType
PERFORM_COMMAND__POST_ORIGINATE: EventType
PERFORM_COMMAND__PRE_UPDATE: EventType
PERFORM_COMMAND__POST_UPDATE: EventType
PERFORM_COMMAND__PRE_COMMIT: EventType
PERFORM_COMMAND__POST_COMMIT: EventType
PERFORM_COMMAND__PRE_DELETE: EventType
PERFORM_COMMAND__POST_DELETE: EventType
PERFORM_COMMAND__PRE_ENTER_IN_ERROR: EventType
PERFORM_COMMAND__POST_ENTER_IN_ERROR: EventType
PERFORM_COMMAND__PRE_EXECUTE_ACTION: EventType
PERFORM_COMMAND__POST_EXECUTE_ACTION: EventType
PERFORM_COMMAND__POST_INSERTED_INTO_NOTE: EventType
PERFORM__PERFORM__PRE_SEARCH: EventType
PERFORM__PERFORM__POST_SEARCH: EventType
PHYSICAL_EXAM_COMMAND__PRE_ORIGINATE: EventType
PHYSICAL_EXAM_COMMAND__POST_ORIGINATE: EventType
PHYSICAL_EXAM_COMMAND__PRE_UPDATE: EventType
PHYSICAL_EXAM_COMMAND__POST_UPDATE: EventType
PHYSICAL_EXAM_COMMAND__PRE_COMMIT: EventType
PHYSICAL_EXAM_COMMAND__POST_COMMIT: EventType
PHYSICAL_EXAM_COMMAND__PRE_DELETE: EventType
PHYSICAL_EXAM_COMMAND__POST_DELETE: EventType
PHYSICAL_EXAM_COMMAND__PRE_ENTER_IN_ERROR: EventType
PHYSICAL_EXAM_COMMAND__POST_ENTER_IN_ERROR: EventType
PHYSICAL_EXAM_COMMAND__PRE_EXECUTE_ACTION: EventType
PHYSICAL_EXAM_COMMAND__POST_EXECUTE_ACTION: EventType
PHYSICAL_EXAM_COMMAND__POST_INSERTED_INTO_NOTE: EventType
PHYSICAL_EXAM__QUESTIONNAIRE__PRE_SEARCH: EventType
PHYSICAL_EXAM__QUESTIONNAIRE__POST_SEARCH: EventType
PLAN_COMMAND__PRE_ORIGINATE: EventType
PLAN_COMMAND__POST_ORIGINATE: EventType
PLAN_COMMAND__PRE_UPDATE: EventType
PLAN_COMMAND__POST_UPDATE: EventType
PLAN_COMMAND__PRE_COMMIT: EventType
PLAN_COMMAND__POST_COMMIT: EventType
PLAN_COMMAND__PRE_DELETE: EventType
PLAN_COMMAND__POST_DELETE: EventType
PLAN_COMMAND__PRE_ENTER_IN_ERROR: EventType
PLAN_COMMAND__POST_ENTER_IN_ERROR: EventType
PLAN_COMMAND__PRE_EXECUTE_ACTION: EventType
PLAN_COMMAND__POST_EXECUTE_ACTION: EventType
PLAN_COMMAND__POST_INSERTED_INTO_NOTE: EventType
PRESCRIBE_COMMAND__PRE_ORIGINATE: EventType
PRESCRIBE_COMMAND__POST_ORIGINATE: EventType
PRESCRIBE_COMMAND__PRE_UPDATE: EventType
PRESCRIBE_COMMAND__POST_UPDATE: EventType
PRESCRIBE_COMMAND__PRE_COMMIT: EventType
PRESCRIBE_COMMAND__POST_COMMIT: EventType
PRESCRIBE_COMMAND__PRE_DELETE: EventType
PRESCRIBE_COMMAND__POST_DELETE: EventType
PRESCRIBE_COMMAND__PRE_ENTER_IN_ERROR: EventType
PRESCRIBE_COMMAND__POST_ENTER_IN_ERROR: EventType
PRESCRIBE_COMMAND__PRE_EXECUTE_ACTION: EventType
PRESCRIBE_COMMAND__POST_EXECUTE_ACTION: EventType
PRESCRIBE_COMMAND__POST_INSERTED_INTO_NOTE: EventType
PRESCRIBE__PRESCRIBE__POST_SEARCH: EventType
PRESCRIBE__PRESCRIBE__PRE_SEARCH: EventType
PRESCRIBE__INDICATIONS__PRE_SEARCH: EventType
PRESCRIBE__INDICATIONS__POST_SEARCH: EventType
PRESCRIBE__PHARMACY__PRE_SEARCH: EventType
PRESCRIBE__PHARMACY__POST_SEARCH: EventType
PRESCRIBE__SUPERVISING_PROVIDER__POST_SEARCH: EventType
PRESCRIBE__SUPERVISING_PROVIDER__PRE_SEARCH: EventType
QUESTIONNAIRE_COMMAND__PRE_ORIGINATE: EventType
QUESTIONNAIRE_COMMAND__POST_ORIGINATE: EventType
QUESTIONNAIRE_COMMAND__PRE_UPDATE: EventType
QUESTIONNAIRE_COMMAND__POST_UPDATE: EventType
QUESTIONNAIRE_COMMAND__PRE_COMMIT: EventType
QUESTIONNAIRE_COMMAND__POST_COMMIT: EventType
QUESTIONNAIRE_COMMAND__PRE_DELETE: EventType
QUESTIONNAIRE_COMMAND__POST_DELETE: EventType
QUESTIONNAIRE_COMMAND__PRE_ENTER_IN_ERROR: EventType
QUESTIONNAIRE_COMMAND__POST_ENTER_IN_ERROR: EventType
QUESTIONNAIRE_COMMAND__PRE_EXECUTE_ACTION: EventType
QUESTIONNAIRE_COMMAND__POST_EXECUTE_ACTION: EventType
QUESTIONNAIRE_COMMAND__POST_INSERTED_INTO_NOTE: EventType
QUESTIONNAIRE__QUESTIONNAIRE__POST_SEARCH: EventType
QUESTIONNAIRE__QUESTIONNAIRE__PRE_SEARCH: EventType
REASON_FOR_VISIT_COMMAND__PRE_ORIGINATE: EventType
REASON_FOR_VISIT_COMMAND__POST_ORIGINATE: EventType
REASON_FOR_VISIT_COMMAND__PRE_UPDATE: EventType
REASON_FOR_VISIT_COMMAND__POST_UPDATE: EventType
REASON_FOR_VISIT_COMMAND__PRE_COMMIT: EventType
REASON_FOR_VISIT_COMMAND__POST_COMMIT: EventType
REASON_FOR_VISIT_COMMAND__PRE_DELETE: EventType
REASON_FOR_VISIT_COMMAND__POST_DELETE: EventType
REASON_FOR_VISIT_COMMAND__PRE_ENTER_IN_ERROR: EventType
REASON_FOR_VISIT_COMMAND__POST_ENTER_IN_ERROR: EventType
REASON_FOR_VISIT_COMMAND__PRE_EXECUTE_ACTION: EventType
REASON_FOR_VISIT_COMMAND__POST_EXECUTE_ACTION: EventType
REASON_FOR_VISIT_COMMAND__POST_INSERTED_INTO_NOTE: EventType
REASON_FOR_VISIT__CODING__POST_SEARCH: EventType
REASON_FOR_VISIT__CODING__PRE_SEARCH: EventType
REFER_COMMAND__PRE_ORIGINATE: EventType
REFER_COMMAND__POST_ORIGINATE: EventType
REFER_COMMAND__PRE_UPDATE: EventType
REFER_COMMAND__POST_UPDATE: EventType
REFER_COMMAND__PRE_COMMIT: EventType
REFER_COMMAND__POST_COMMIT: EventType
REFER_COMMAND__PRE_DELETE: EventType
REFER_COMMAND__POST_DELETE: EventType
REFER_COMMAND__PRE_ENTER_IN_ERROR: EventType
REFER_COMMAND__POST_ENTER_IN_ERROR: EventType
REFER_COMMAND__PRE_EXECUTE_ACTION: EventType
REFER_COMMAND__POST_EXECUTE_ACTION: EventType
REFER_COMMAND__POST_INSERTED_INTO_NOTE: EventType
REFER__REFER_TO__POST_SEARCH: EventType
REFER__REFER_TO__PRE_SEARCH: EventType
REFER__INDICATIONS__POST_SEARCH: EventType
REFER__INDICATIONS__PRE_SEARCH: EventType
REFER__DOCUMENTS_TO_INCLUDE__POST_SEARCH: EventType
REFER__DOCUMENTS_TO_INCLUDE__PRE_SEARCH: EventType
REFER__LINKED_ITEMS__POST_SEARCH: EventType
REFER__LINKED_ITEMS_INCLUDE__PRE_SEARCH: EventType
REFILL_COMMAND__PRE_ORIGINATE: EventType
REFILL_COMMAND__POST_ORIGINATE: EventType
REFILL_COMMAND__PRE_UPDATE: EventType
REFILL_COMMAND__POST_UPDATE: EventType
REFILL_COMMAND__PRE_COMMIT: EventType
REFILL_COMMAND__POST_COMMIT: EventType
REFILL_COMMAND__PRE_DELETE: EventType
REFILL_COMMAND__POST_DELETE: EventType
REFILL_COMMAND__PRE_ENTER_IN_ERROR: EventType
REFILL_COMMAND__POST_ENTER_IN_ERROR: EventType
REFILL_COMMAND__PRE_EXECUTE_ACTION: EventType
REFILL_COMMAND__POST_EXECUTE_ACTION: EventType
REFILL_COMMAND__POST_INSERTED_INTO_NOTE: EventType
REFILL__PRESCRIBE__PRE_SEARCH: EventType
REFILL__PRESCRIBE__POST_SEARCH: EventType
REFILL__INDICATIONS__PRE_SEARCH: EventType
REFILL__INDICATIONS__POST_SEARCH: EventType
REFILL__PHARMACY__PRE_SEARCH: EventType
REFILL__PHARMACY__POST_SEARCH: EventType
REFILL__SUPERVISING_PROVIDER__PRE_SEARCH: EventType
REFILL__SUPERVISING_PROVIDER__POST_SEARCH: EventType
REMOVE_ALLERGY_COMMAND__PRE_ORIGINATE: EventType
REMOVE_ALLERGY_COMMAND__POST_ORIGINATE: EventType
REMOVE_ALLERGY_COMMAND__PRE_UPDATE: EventType
REMOVE_ALLERGY_COMMAND__POST_UPDATE: EventType
REMOVE_ALLERGY_COMMAND__PRE_COMMIT: EventType
REMOVE_ALLERGY_COMMAND__POST_COMMIT: EventType
REMOVE_ALLERGY_COMMAND__PRE_DELETE: EventType
REMOVE_ALLERGY_COMMAND__POST_DELETE: EventType
REMOVE_ALLERGY_COMMAND__PRE_ENTER_IN_ERROR: EventType
REMOVE_ALLERGY_COMMAND__POST_ENTER_IN_ERROR: EventType
REMOVE_ALLERGY_COMMAND__PRE_EXECUTE_ACTION: EventType
REMOVE_ALLERGY_COMMAND__POST_EXECUTE_ACTION: EventType
REMOVE_ALLERGY_COMMAND__POST_INSERTED_INTO_NOTE: EventType
REMOVE_ALLERGY__ALLERGY__PRE_SEARCH: EventType
REMOVE_ALLERGY__ALLERGY__POST_SEARCH: EventType
RESOLVE_CONDITION_COMMAND__PRE_ORIGINATE: EventType
RESOLVE_CONDITION_COMMAND__POST_ORIGINATE: EventType
RESOLVE_CONDITION_COMMAND__PRE_UPDATE: EventType
RESOLVE_CONDITION_COMMAND__POST_UPDATE: EventType
RESOLVE_CONDITION_COMMAND__PRE_COMMIT: EventType
RESOLVE_CONDITION_COMMAND__POST_COMMIT: EventType
RESOLVE_CONDITION_COMMAND__PRE_DELETE: EventType
RESOLVE_CONDITION_COMMAND__POST_DELETE: EventType
RESOLVE_CONDITION_COMMAND__PRE_ENTER_IN_ERROR: EventType
RESOLVE_CONDITION_COMMAND__POST_ENTER_IN_ERROR: EventType
RESOLVE_CONDITION_COMMAND__PRE_EXECUTE_ACTION: EventType
RESOLVE_CONDITION_COMMAND__POST_EXECUTE_ACTION: EventType
RESOLVE_CONDITION_COMMAND__POST_INSERTED_INTO_NOTE: EventType
RESOLVE_CONDITION__CONDITION__PRE_SEARCH: EventType
RESOLVE_CONDITION__CONDITION__POST_SEARCH: EventType
ROS_COMMAND__PRE_ORIGINATE: EventType
ROS_COMMAND__POST_ORIGINATE: EventType
ROS_COMMAND__PRE_UPDATE: EventType
ROS_COMMAND__POST_UPDATE: EventType
ROS_COMMAND__PRE_COMMIT: EventType
ROS_COMMAND__POST_COMMIT: EventType
ROS_COMMAND__PRE_DELETE: EventType
ROS_COMMAND__POST_DELETE: EventType
ROS_COMMAND__PRE_ENTER_IN_ERROR: EventType
ROS_COMMAND__POST_ENTER_IN_ERROR: EventType
ROS_COMMAND__PRE_EXECUTE_ACTION: EventType
ROS_COMMAND__POST_EXECUTE_ACTION: EventType
ROS_COMMAND__POST_INSERTED_INTO_NOTE: EventType
ROS__QUESTIONNAIRE__PRE_SEARCH: EventType
ROS__QUESTIONNAIRE__POST_SEARCH: EventType
SNOOZE_PROTOCOL_COMMAND__PRE_ORIGINATE: EventType
SNOOZE_PROTOCOL_COMMAND__POST_ORIGINATE: EventType
SNOOZE_PROTOCOL_COMMAND__PRE_UPDATE: EventType
SNOOZE_PROTOCOL_COMMAND__POST_UPDATE: EventType
SNOOZE_PROTOCOL_COMMAND__PRE_COMMIT: EventType
SNOOZE_PROTOCOL_COMMAND__POST_COMMIT: EventType
SNOOZE_PROTOCOL_COMMAND__PRE_DELETE: EventType
SNOOZE_PROTOCOL_COMMAND__POST_DELETE: EventType
SNOOZE_PROTOCOL_COMMAND__PRE_ENTER_IN_ERROR: EventType
SNOOZE_PROTOCOL_COMMAND__POST_ENTER_IN_ERROR: EventType
SNOOZE_PROTOCOL_COMMAND__PRE_EXECUTE_ACTION: EventType
SNOOZE_PROTOCOL_COMMAND__POST_EXECUTE_ACTION: EventType
SNOOZE_PROTOCOL__PROTOCOL__PRE_SEARCH: EventType
SNOOZE_PROTOCOL__PROTOCOL__POST_SEARCH: EventType
STOP_MEDICATION_COMMAND__PRE_ORIGINATE: EventType
STOP_MEDICATION_COMMAND__POST_ORIGINATE: EventType
STOP_MEDICATION_COMMAND__PRE_UPDATE: EventType
STOP_MEDICATION_COMMAND__POST_UPDATE: EventType
STOP_MEDICATION_COMMAND__PRE_COMMIT: EventType
STOP_MEDICATION_COMMAND__POST_COMMIT: EventType
STOP_MEDICATION_COMMAND__PRE_DELETE: EventType
STOP_MEDICATION_COMMAND__POST_DELETE: EventType
STOP_MEDICATION_COMMAND__PRE_ENTER_IN_ERROR: EventType
STOP_MEDICATION_COMMAND__POST_ENTER_IN_ERROR: EventType
STOP_MEDICATION_COMMAND__PRE_EXECUTE_ACTION: EventType
STOP_MEDICATION_COMMAND__POST_EXECUTE_ACTION: EventType
STOP_MEDICATION_COMMAND__POST_INSERTED_INTO_NOTE: EventType
STOP_MEDICATION__MEDICATION__PRE_SEARCH: EventType
STOP_MEDICATION__MEDICATION__POST_SEARCH: EventType
STRUCTURED_ASSESSMENT_COMMAND__PRE_ORIGINATE: EventType
STRUCTURED_ASSESSMENT_COMMAND__POST_ORIGINATE: EventType
STRUCTURED_ASSESSMENT_COMMAND__PRE_UPDATE: EventType
STRUCTURED_ASSESSMENT_COMMAND__POST_UPDATE: EventType
STRUCTURED_ASSESSMENT_COMMAND__PRE_COMMIT: EventType
STRUCTURED_ASSESSMENT_COMMAND__POST_COMMIT: EventType
STRUCTURED_ASSESSMENT_COMMAND__PRE_DELETE: EventType
STRUCTURED_ASSESSMENT_COMMAND__POST_DELETE: EventType
STRUCTURED_ASSESSMENT_COMMAND__PRE_ENTER_IN_ERROR: EventType
STRUCTURED_ASSESSMENT_COMMAND__POST_ENTER_IN_ERROR: EventType
STRUCTURED_ASSESSMENT_COMMAND__PRE_EXECUTE_ACTION: EventType
STRUCTURED_ASSESSMENT_COMMAND__POST_EXECUTE_ACTION: EventType
STRUCTURED_ASSESSMENT_COMMAND__POST_INSERTED_INTO_NOTE: EventType
STRUCTURED_ASSESSMENT__QUESTIONNAIRE__PRE_SEARCH: EventType
STRUCTURED_ASSESSMENT__QUESTIONNAIRE__POST_SEARCH: EventType
SURGICAL_HISTORY_COMMAND__PRE_ORIGINATE: EventType
SURGICAL_HISTORY_COMMAND__POST_ORIGINATE: EventType
SURGICAL_HISTORY_COMMAND__PRE_UPDATE: EventType
SURGICAL_HISTORY_COMMAND__POST_UPDATE: EventType
SURGICAL_HISTORY_COMMAND__PRE_COMMIT: EventType
SURGICAL_HISTORY_COMMAND__POST_COMMIT: EventType
SURGICAL_HISTORY_COMMAND__PRE_DELETE: EventType
SURGICAL_HISTORY_COMMAND__POST_DELETE: EventType
SURGICAL_HISTORY_COMMAND__PRE_ENTER_IN_ERROR: EventType
SURGICAL_HISTORY_COMMAND__POST_ENTER_IN_ERROR: EventType
SURGICAL_HISTORY_COMMAND__PRE_EXECUTE_ACTION: EventType
SURGICAL_HISTORY_COMMAND__POST_EXECUTE_ACTION: EventType
SURGICAL_HISTORY_COMMAND__POST_INSERTED_INTO_NOTE: EventType
SURGICAL_HISTORY__PAST_SURGICAL_HISTORY__PRE_SEARCH: EventType
SURGICAL_HISTORY__PAST_SURGICAL_HISTORY__POST_SEARCH: EventType
TASK_COMMAND__PRE_ORIGINATE: EventType
TASK_COMMAND__POST_ORIGINATE: EventType
TASK_COMMAND__PRE_UPDATE: EventType
TASK_COMMAND__POST_UPDATE: EventType
TASK_COMMAND__PRE_COMMIT: EventType
TASK_COMMAND__POST_COMMIT: EventType
TASK_COMMAND__PRE_DELETE: EventType
TASK_COMMAND__POST_DELETE: EventType
TASK_COMMAND__PRE_ENTER_IN_ERROR: EventType
TASK_COMMAND__POST_ENTER_IN_ERROR: EventType
TASK_COMMAND__PRE_EXECUTE_ACTION: EventType
TASK_COMMAND__POST_EXECUTE_ACTION: EventType
TASK_COMMAND__POST_INSERTED_INTO_NOTE: EventType
TASK__ASSIGN_TO__PRE_SEARCH: EventType
TASK__ASSIGN_TO__POST_SEARCH: EventType
TASK__LABELS__PRE_SEARCH: EventType
TASK__LABELS__POST_SEARCH: EventType
UPDATE_DIAGNOSIS_COMMAND__PRE_ORIGINATE: EventType
UPDATE_DIAGNOSIS_COMMAND__POST_ORIGINATE: EventType
UPDATE_DIAGNOSIS_COMMAND__PRE_UPDATE: EventType
UPDATE_DIAGNOSIS_COMMAND__POST_UPDATE: EventType
UPDATE_DIAGNOSIS_COMMAND__PRE_COMMIT: EventType
UPDATE_DIAGNOSIS_COMMAND__POST_COMMIT: EventType
UPDATE_DIAGNOSIS_COMMAND__PRE_DELETE: EventType
UPDATE_DIAGNOSIS_COMMAND__POST_DELETE: EventType
UPDATE_DIAGNOSIS_COMMAND__PRE_ENTER_IN_ERROR: EventType
UPDATE_DIAGNOSIS_COMMAND__POST_ENTER_IN_ERROR: EventType
UPDATE_DIAGNOSIS_COMMAND__PRE_EXECUTE_ACTION: EventType
UPDATE_DIAGNOSIS_COMMAND__POST_EXECUTE_ACTION: EventType
UPDATE_DIAGNOSIS_COMMAND__POST_INSERTED_INTO_NOTE: EventType
UPDATE_DIAGNOSIS__CONDITION__PRE_SEARCH: EventType
UPDATE_DIAGNOSIS__CONDITION__POST_SEARCH: EventType
UPDATE_DIAGNOSIS__NEW_CONDITION__PRE_SEARCH: EventType
UPDATE_DIAGNOSIS__NEW_CONDITION__POST_SEARCH: EventType
UPDATE_GOAL_COMMAND__PRE_ORIGINATE: EventType
UPDATE_GOAL_COMMAND__POST_ORIGINATE: EventType
UPDATE_GOAL_COMMAND__PRE_UPDATE: EventType
UPDATE_GOAL_COMMAND__POST_UPDATE: EventType
UPDATE_GOAL_COMMAND__PRE_COMMIT: EventType
UPDATE_GOAL_COMMAND__POST_COMMIT: EventType
UPDATE_GOAL_COMMAND__PRE_DELETE: EventType
UPDATE_GOAL_COMMAND__POST_DELETE: EventType
UPDATE_GOAL_COMMAND__PRE_ENTER_IN_ERROR: EventType
UPDATE_GOAL_COMMAND__POST_ENTER_IN_ERROR: EventType
UPDATE_GOAL_COMMAND__PRE_EXECUTE_ACTION: EventType
UPDATE_GOAL_COMMAND__POST_EXECUTE_ACTION: EventType
UPDATE_GOAL_COMMAND__POST_INSERTED_INTO_NOTE: EventType
UPDATE_GOAL__GOAL_STATEMENT__PRE_SEARCH: EventType
UPDATE_GOAL__GOAL_STATEMENT__POST_SEARCH: EventType
VITALS_COMMAND__PRE_ORIGINATE: EventType
VITALS_COMMAND__POST_ORIGINATE: EventType
VITALS_COMMAND__PRE_UPDATE: EventType
VITALS_COMMAND__POST_UPDATE: EventType
VITALS_COMMAND__PRE_COMMIT: EventType
VITALS_COMMAND__POST_COMMIT: EventType
VITALS_COMMAND__PRE_DELETE: EventType
VITALS_COMMAND__POST_DELETE: EventType
VITALS_COMMAND__PRE_ENTER_IN_ERROR: EventType
VITALS_COMMAND__POST_ENTER_IN_ERROR: EventType
VITALS_COMMAND__PRE_EXECUTE_ACTION: EventType
VITALS_COMMAND__POST_EXECUTE_ACTION: EventType
VITALS_COMMAND__POST_INSERTED_INTO_NOTE: EventType
ASSESS_CODING_GAP_COMMAND__PRE_ORIGINATE: EventType
ASSESS_CODING_GAP_COMMAND__POST_ORIGINATE: EventType
ASSESS_CODING_GAP_COMMAND__PRE_UPDATE: EventType
ASSESS_CODING_GAP_COMMAND__POST_UPDATE: EventType
ASSESS_CODING_GAP_COMMAND__PRE_COMMIT: EventType
ASSESS_CODING_GAP_COMMAND__POST_COMMIT: EventType
ASSESS_CODING_GAP_COMMAND__PRE_DELETE: EventType
ASSESS_CODING_GAP_COMMAND__POST_DELETE: EventType
ASSESS_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR: EventType
ASSESS_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR: EventType
ASSESS_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION: EventType
ASSESS_CODING_GAP_COMMAND__POST_EXECUTE_ACTION: EventType
ASSESS_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE: EventType
ASSESS_CODING_GAP__DIAGNOSE__PRE_SEARCH: EventType
ASSESS_CODING_GAP__DIAGNOSE__POST_SEARCH: EventType
CREATE_CODING_GAP_COMMAND__PRE_ORIGINATE: EventType
CREATE_CODING_GAP_COMMAND__POST_ORIGINATE: EventType
CREATE_CODING_GAP_COMMAND__PRE_UPDATE: EventType
CREATE_CODING_GAP_COMMAND__POST_UPDATE: EventType
CREATE_CODING_GAP_COMMAND__PRE_COMMIT: EventType
CREATE_CODING_GAP_COMMAND__POST_COMMIT: EventType
CREATE_CODING_GAP_COMMAND__PRE_DELETE: EventType
CREATE_CODING_GAP_COMMAND__POST_DELETE: EventType
CREATE_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR: EventType
CREATE_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR: EventType
CREATE_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION: EventType
CREATE_CODING_GAP_COMMAND__POST_EXECUTE_ACTION: EventType
CREATE_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE: EventType
CREATE_CODING_GAP__DIAGNOSE__PRE_SEARCH: EventType
CREATE_CODING_GAP__DIAGNOSE__POST_SEARCH: EventType
VALIDATE_CODING_GAP_COMMAND__PRE_ORIGINATE: EventType
VALIDATE_CODING_GAP_COMMAND__POST_ORIGINATE: EventType
VALIDATE_CODING_GAP_COMMAND__PRE_UPDATE: EventType
VALIDATE_CODING_GAP_COMMAND__POST_UPDATE: EventType
VALIDATE_CODING_GAP_COMMAND__PRE_COMMIT: EventType
VALIDATE_CODING_GAP_COMMAND__POST_COMMIT: EventType
VALIDATE_CODING_GAP_COMMAND__PRE_DELETE: EventType
VALIDATE_CODING_GAP_COMMAND__POST_DELETE: EventType
VALIDATE_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR: EventType
VALIDATE_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR: EventType
VALIDATE_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION: EventType
VALIDATE_CODING_GAP_COMMAND__POST_EXECUTE_ACTION: EventType
VALIDATE_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE: EventType
DEFER_CODING_GAP_COMMAND__PRE_ORIGINATE: EventType
DEFER_CODING_GAP_COMMAND__POST_ORIGINATE: EventType
DEFER_CODING_GAP_COMMAND__PRE_UPDATE: EventType
DEFER_CODING_GAP_COMMAND__POST_UPDATE: EventType
DEFER_CODING_GAP_COMMAND__PRE_COMMIT: EventType
DEFER_CODING_GAP_COMMAND__POST_COMMIT: EventType
DEFER_CODING_GAP_COMMAND__PRE_DELETE: EventType
DEFER_CODING_GAP_COMMAND__POST_DELETE: EventType
DEFER_CODING_GAP_COMMAND__PRE_ENTER_IN_ERROR: EventType
DEFER_CODING_GAP_COMMAND__POST_ENTER_IN_ERROR: EventType
DEFER_CODING_GAP_COMMAND__PRE_EXECUTE_ACTION: EventType
DEFER_CODING_GAP_COMMAND__POST_EXECUTE_ACTION: EventType
DEFER_CODING_GAP_COMMAND__POST_INSERTED_INTO_NOTE: EventType
CHANGE_MEDICATION_COMMAND__PRE_ORIGINATE: EventType
CHANGE_MEDICATION_COMMAND__POST_ORIGINATE: EventType
CHANGE_MEDICATION_COMMAND__PRE_UPDATE: EventType
CHANGE_MEDICATION_COMMAND__POST_UPDATE: EventType
CHANGE_MEDICATION_COMMAND__PRE_COMMIT: EventType
CHANGE_MEDICATION_COMMAND__POST_COMMIT: EventType
CHANGE_MEDICATION_COMMAND__PRE_DELETE: EventType
CHANGE_MEDICATION_COMMAND__POST_DELETE: EventType
CHANGE_MEDICATION_COMMAND__PRE_ENTER_IN_ERROR: EventType
CHANGE_MEDICATION_COMMAND__POST_ENTER_IN_ERROR: EventType
CHANGE_MEDICATION_COMMAND__PRE_EXECUTE_ACTION: EventType
CHANGE_MEDICATION_COMMAND__POST_EXECUTE_ACTION: EventType
CHANGE_MEDICATION_COMMAND__POST_INSERTED_INTO_NOTE: EventType
CHANGE_MEDICATION__MEDICATION__PRE_SEARCH: EventType
CHANGE_MEDICATION__MEDICATION__POST_SEARCH: EventType
SHOW_NOTE_HEADER_BUTTON: EventType
SHOW_NOTE_FOOTER_BUTTON: EventType
ACTION_BUTTON_CLICKED: EventType
PATIENT_CHART__CONDITIONS: EventType
PATIENT_CHART_SUMMARY__SECTION_CONFIGURATION: EventType
PATIENT_PROFILE__SECTION_CONFIGURATION: EventType
PATIENT_PROFILE__ADD_PHARMACY__POST_SEARCH: EventType
CLAIM__CONDITIONS: EventType
PLUGIN_CREATED: EventType
PLUGIN_UPDATED: EventType
APPLICATION__ON_OPEN: EventType
PATIENT_PORTAL__GET_FORMS: EventType
PATIENT_PORTAL__APPOINTMENT_CANCELED: EventType
PATIENT_PORTAL__APPOINTMENT_RESCHEDULED: EventType
PATIENT_PORTAL__APPOINTMENT_CAN_BE_CANCELED: EventType
PATIENT_PORTAL__APPOINTMENT_CAN_BE_RESCHEDULED: EventType
PATIENT_PORTAL__APPOINTMENTS__SLOTS__POST_SEARCH: EventType
PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__PRE_SEARCH: EventType
PATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__POST_SEARCH: EventType
PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__PRE_SEARCH: EventType
PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__POST_SEARCH: EventType
PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__PRE_SEARCH: EventType
PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__POST_SEARCH: EventType
PATIENT_PORTAL__APPOINTMENT_CAN_SHOW_MEETING_LINK: EventType
PATIENT_PORTAL__GET_APPLICATION_CONFIGURATION: EventType
PATIENT_PORTAL__MENU_CONFIGURATION: EventType
PATIENT_PORTAL__WIDGET_CONFIGURATION: EventType
SHOW_CHART_SUMMARY_SOCIAL_DETERMINANTS_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_GOALS_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_CONDITIONS_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_MEDICATIONS_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_ALLERGIES_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_CARE_TEAMS_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_VITALS_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_IMMUNIZATIONS_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_SURGICAL_HISTORY_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_FAMILY_HISTORY_SECTION_BUTTON: EventType
SHOW_CHART_SUMMARY_CODING_GAPS_SECTION_BUTTON: EventType
SIMPLE_API_AUTHENTICATE: EventType
SIMPLE_API_REQUEST: EventType
SIMPLE_API_WEBSOCKET_AUTHENTICATE: EventType
PATIENT_METADATA__GET_ADDITIONAL_FIELDS: EventType
PATIENT_EXTERNAL_IDENTIFIER_CREATED: EventType
PATIENT_EXTERNAL_IDENTIFIER_UPDATED: EventType
PATIENT_EXTERNAL_IDENTIFIER_DELETED: EventType

class Event(_message.Message):
    __slots__ = ("type", "target", "context", "target_type")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    TARGET_TYPE_FIELD_NUMBER: _ClassVar[int]
    type: EventType
    target: str
    context: str
    target_type: str
    def __init__(self, type: _Optional[_Union[EventType, str]] = ..., target: _Optional[str] = ..., context: _Optional[str] = ..., target_type: _Optional[str] = ...) -> None: ...

class EventResponse(_message.Message):
    __slots__ = ("success", "effects")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    EFFECTS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    effects: _containers.RepeatedCompositeFieldContainer[_effects_pb2.Effect]
    def __init__(self, success: bool = ..., effects: _Optional[_Iterable[_Union[_effects_pb2.Effect, _Mapping]]] = ...) -> None: ...
